#!/bin/bash
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

# S010_main_functions.sh 

CHOOSEDIR="\$(grub_device)/""${GRUB_RELATIVE}""/choose"


#redefine_substitute_files
# Serves us to define the substitute files
# which could be changed by the module
redefine_substitute_files ()
{

# Let's redefine the files to substitute

SUBST_FILES[0]="${SDG_MENU_LST[LEVEL]}";
SUBST_FILES[1]="${SDG_HELP_LST[LEVEL]}";
SUBST_FILES[2]="${SDG_MENU_HEAD[LEVEL]}";
SUBST_FILES[3]="${SDG_MENU_TAIL[LEVEL]}";

}


##variableplus
# This function 
# WAS SUPPOSED TO
# make the variable 
# get a copy from a level below
# It is an auxiliary function of levelplus
# $1 is the variable to modify
variableplus()
{

local TEMPO="$1"

"$TEMPO"[LEVEL]=${TEMPO[$LEVEL]}

#### ${SUBST_FILES[$i]}
} # End of variableplus

# levelplus
# This function is runned when we go into
# another folder. It copies all the variables
# into the next level of the array-variables
# And it also increments by one the level

levelplus()
{

LEVEL=$[$LEVEL + 1]

SDG_TITLE[LEVEL]="${SDG_TITLE[LEVEL - 1]}"
SDG_MODULE_ID[LEVEL]="${SDG_MODULE_ID[LEVEL - 1]}"
SDG_MENU_LST[LEVEL]="${SDG_MENU_LST[LEVEL - 1]}"
SDG_HELP_LST[LEVEL]="${SDG_HELP_LST[LEVEL - 1]}"
SDG_MENU_HEAD[LEVEL]="${SDG_MENU_HEAD[LEVEL - 1]}"
SDG_MENU_TAIL[LEVEL]="${SDG_MENU_TAIL[LEVEL - 1]}"
SDG_MENU_BODY[LEVEL]="${SDG_MENU_BODY[LEVEL - 1]}"
SDG_HELP_TXT[LEVEL]="${SDG_HELP_TXT[LEVEL - 1]}"
SDG_HELP_DIR[LEVEL]="${SDG_HELP_DIR[LEVEL - 1]}"

SDG_PRE_BACK[LEVEL]="${SDG_PRE_BACK[LEVEL - 1]}"
SDG_POST_BACK[LEVEL]="${SDG_POST_BACK[LEVEL - 1]}"
SDG_PRE_CURRENT[LEVEL]="${SDG_PRE_CURRENT[LEVEL - 1]}"
SDG_POST_CURRENT[LEVEL]="${SDG_POST_CURRENT[LEVEL - 1]}"

SDG_MESSAGE_PAUSE[LEVEL]="${SDG_MESSAGE_PAUSE[LEVEL-1]}"

# Let's redefine the files to substitute

redefine_substitute_files


#variableplus SDG_TITLE
#variableplus SDG_MODULE_ID
#variableplus DIRECTORIO_ACTUAL
#variableplus SDG_MENU_LST
#variableplus SDG_AYUDA_LST
#variableplus SDG_MENU_HEAD
#variableplus SDG_MENU_TAIL
#variableplus SDG_MENU_BODY

} # End of levelplus

# This function is runned when we come
# back from another folder
# It only changes level to one less
levelless()
{
LEVEL=$[$LEVEL - 1]

# Let's redefine the files to substitute
unset SUBST_FILES;
unset OPTION;
unset MESSAGE;
redefine_substitute_files

} # End of levelless

# De momento check files no va a comprobar ningun archivo
# Habra que comprobar el sed
# El cp y pocos mas
# checkfiles comprueba
# si comandos como el sed, find u otros
# estan disponibles
checkfiles()
{
echo "No checking of files is performed"
#        [ -x "$dd" ] || abort "Can't find $dd, aborting"
#        [ -f "$stage1" ] || abort "Can't find $stage1, aborting"
#        [ -f "$stage2" ] || abort "Can't find $stage2, aborting"
}


# Creates a sed partial string for substitution
# $1 is the FROM string
# $2 is the TO string
sed_partial_string()
{
	#local FILE="$1"
	local FROM="$1"
	local TO="$2"

# We do some tricks to avoid problems when
# doing substitution with sed

TO=`echo $TO | sed "s/\//\\\\\\\\\\\\//g"`
FROM=`echo $FROM | sed "s/\[/\\\\\\\\\\\\[/g"`
FROM=`echo $FROM | sed "s/\]/\\\\\\\\\\\\]/g"`

echo "s/$FROM/$TO/g"

} # End of sed_partial_string()

# Substitutes the strings found on OPTION array
# and MESSAGE array in the files that are found
# in SUBST_FILES array

# TODO: Use functions for the whiles

substitute_all_files()
{
local OPTION_NUMBER=${#OPTION[@]};
local FILES_NUMBER=${#SUBST_FILES[@]};
local MESSAGE_NUMBER=${#MESSAGE[@]};
local i=0; local j=0;

files_in_folder="";
files_to_find="";
# Define in find format the files to find
i=0;
while [ $i -le $[$FILES_NUMBER - 1] ] ; do

  # if $i == 0 as_it_is
  # if ! $i == 0 -o as_it_is

  if [ $i -eq 0 ] ; then
files_to_find=`echo "$files_to_find" "-name ${SUBST_FILES[$i]}"`
  else
files_to_find=`echo "$files_to_find" "-o -name ${SUBST_FILES[$i]}"`
  fi
# Iterate file
i=$[$i + 1]
done


# Define in sed format the strings to replace if we
# can replace more than 2 strings in only one sed command. # Yes, we can with ;


sed_string="";

			# Substitute choose folder
			sed_string="${sed_string}"`sed_partial_string  "CHOOSEDIR" "${CHOOSEDIR}"`
			# Substitute sgdlinksto string
			sed_string="${sed_string}"";"`sed_partial_string  "SGDLINKSTO" "${PROGRAM_RELATIVE}""/""${SGD_CURRENT_LANG_DIR}"`
			# Substitute sgdrelative string
			sed_string="${sed_string}"";"`sed_partial_string  "SGDRELATIVE" "${PROGRAM_RELATIVE}"`

			j=0;
			# Substitute option array
			while [ $j -le $[$OPTION_NUMBER - 1] ] ; do
				sed_string="${sed_string}"";"`sed_partial_string  "OPTION[$j]" "${OPTION[$j]}"`
				j=$[$j + 1]
			done
			j=0;

			# Substitute message array
			while [ $j -le $[$MESSAGE_NUMBER - 1] ] ; do
				sed_string="${sed_string}"";"`sed_partial_string  "MESSAGE[$j]" "${MESSAGE[$j]}"`
				j=$[$j + 1]
			done
			j=0;



			

			# Substitute current dir
			sed_string="${sed_string}"";"`sed_partial_string  "$SDG_CURRENT_DIR_STRING" "${CURRENT_FOLDER[LEVEL]}"`

			# Substitute up dir
			sed_string="${sed_string}"";"`sed_partial_string  "$SDG_UP_DIR_STRING" "${CURRENT_FOLDER[LEVEL-1]}"`

			# Substitute grub boot device
			sed_string="${sed_string}"";"`sed_partial_string  SDG_DEVICE "$SDG_DEVICE"`





# Execute the find command to find them
find . -maxdepth 1 \( -type f -a \( $files_to_find \) \) | xargs sed "$sed_string" -i 


} # End of substitute_all_files

# The first level value must be 0
# Because arrays in bash begins in 0
LEVEL=0;
