#!/bin/bash
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

set -x
set -v

# options: 
# Build a cdrom iso
# Build floppies
# Build monolingual cdroms
# Test cdrom from qemu


clean_target()
{
# Prepare target folder
MAGIC_TARGET="../test_fs"


if [ -d  $MAGIC_TARGET ] ; then
  # If target folder exists we should delete it and create it again.
  rm -Rf $MAGIC_TARGET
  mkdir -p $MAGIC_TARGET
else
  # If target folder does exit we create it.
  mkdir -p $MAGIC_TARGET;
fi
}

usage()
{
        cat <<EOF
Usage: $0 [options] cdromiso /path/to/iso
Creates ${MAGIC_NAME} cdrom iso in /path/to/iso file.

Usage: $0 [options] multilingualiso
Creates ${MAGIC_NAME} cdrom iso in release folder.

Usage: $0 [options] floppies
Creates ${MAGIC_NAME} floppy images in release folder.

Usage: $0 [options] monocdromiso
Creates ${MAGIC_NAME} monolingual cdrom isos in release folder.

Usage: $0 [options] qemutest
Creates ${MAGIC_NAME} cdrom temporarily and runs it in qemu

Usage: $0 [options] usbs
Creates a ${MAGIC_NAME} usb tar.gz per language.

Usage: $0 [options] fs
Creates a ${MAGIC_NAME} filesystem in test_fs without copying /boot.



options:
        -h, --help      print this message and exit

EOF
        exit 1
}


common_setup()
{

# Copy /boot contents to to FS_TARGET
mkdir -p ${FS_TARGET}/boot
if cp -R ../boot/* ${FS_TARGET}/boot ; then
echo -e "GREAT!: We could copy ../boot folder into ${FS_TARGET} folder\n";
else
echo -e "ERROR: We could NOT copy ../boot folder into ${FS_TARGET} folder\n";
exit 1;
fi

# Update root menu.lst


cp ./root_cd_menu.lst ${MAGIC_TARGET}/boot/grub/menu.lst

}


##############################################################
#########           MAIN PROGRAM	######################
##############################################################

MAGIC_FOLDER="dev_sgd"
MAGIC_NAME="Super Grub Disk"
MAGIC_RELEASE="release"

# Check magic folder

	if [ ! -d "$MAGIC_FOLDER" ] ;   then
	echo -e "ERROR: $MAGIC_FOLDER folder is inaccesible\n";
	echo -e "ABORTING!";
	exit 1;
	fi

# Get data from configure
cd "${MAGIC_FOLDER}"
source ./sgrub_configure.sh


case "$1" in
        -h | --help)
                usage
                ;;
	cdromiso)
		if [ ! -n "$2" ] ; then
		echo -e "ERROR:\n";
		echo -e "Please specify the ISO where you want to store SGD\n"
		echo -e "e.g. \n"
		echo -e "$0 cdromiso /tmp/sgd_0.xx.iso\n"
		exit 1
		else
		clean_target
		common_setup
			if ! ./build_cdrom_iso.sh "$2" ; then
				echo "An error happened"
			fi

		fi
		;;
	multilingualiso)
		clean_target
		common_setup
			if ! ./build_multilingual_iso.sh ; then
				echo "An error happened"
			fi
		;;

	floppies)
		clean_target
		common_setup
			if ! ./build_floppies.sh ; then
				echo "An error happened"
			fi
		;;
	monocdromiso)
		clean_target
		common_setup
		./build_monolinguals_cds.sh
		;;
	qemutest)
		clean_target
		common_setup
		./test_cdrom_with_qemu.sh
		;;
	usbs)
		clean_target
		common_setup
		./build_usbs.sh
		;;
	fs)
		./build_cdrom_fs.sh
		;;



        *)
		usage
                ;;
esac